@@ -1,5 +1,5 @@
-package Finance::AMEX::Transaction::EPPRC;
-$Finance::AMEX::Transaction::EPPRC::VERSION = '0.004';
+package Finance::AMEX::Transaction::EPPRC 0.005;
+
 use strict;
 use warnings;
 
@@ -33,61 +33,65 @@ sub new {
     TRAILER           => 'Finance::AMEX::Transaction::EPPRC::Trailer',
   };
 
-  my $self = bless {
-    _type_map => $type_map,
-  }, $class;
+  my $self = bless {_type_map => $type_map}, $class;
 
   return $self;
 }
 
+sub file_format  {return 'N/A'}
+sub file_version {return 'N/A'}
+
+sub line_indicator {
+  my ($self, $line) = @_;
+
+  return if not defined $line;
+
+  my $header_trailer_indicator = substr($line, 0, 5);
+
+  my $indicator_map = {
+    DFHDR => 'HEADER',
+    DFTRL => 'TRAILER',
+  };
+
+  if (exists $indicator_map->{$header_trailer_indicator}) {
+    return $indicator_map->{$header_trailer_indicator};
+  }
+
+  # if it is not a header or trailer, we need to look deeper
+  my $summary_detail_indicator = join('-', substr($line, 42, 1), substr($line, 43, 2));
+
+  my $summary_map = {
+    '1-00' => 'SUMMARY',
+    '2-10' => 'SOC_DETAIL',
+    '2-12' => 'SOC_PRICING',
+    '3-11' => 'ROC_DETAIL',
+    '3-13' => 'ROC_PRICING',
+    '2-20' => 'CHARGEBACK_DETAIL',
+    '2-30' => 'ADJUSTMENT_DETAIL',
+    '2-40' => 'OTHER_DETAIL',
+    '2-41' => 'OTHER_DETAIL',
+    '2-50' => 'OTHER_DETAIL',
+  };
+
+  if (exists $summary_map->{$summary_detail_indicator}) {
+    return $summary_map->{$summary_detail_indicator};
+  }
+
+  # we don't know what it is!
+  return;
+}
+
 sub parse_line {
   my ($self, $line) = @_;
 
   return if not defined $line;
 
-  my $header_trailer_indicator = substr($line, 0, 5);
+  my $indicator = $self->line_indicator($line);
 
-  # DFHDR = header
-  # DFTRL = trailer
-
-  # 1-00 = Summary
-  # 2-10 = SOC detail
-  # 2-12 = SOC pricing
-  # 3-11 = ROC detail
-  # 3-13 = ROC pricing
-  # 2-20 = Chargeback detail
-  # 2-30 = Adjustment detail
-  # 2-40, 2-41, 2-50 = Other Fees and Revenues detail
-
-  my $indicator = 'UNKNOWN';
-
-  if ($header_trailer_indicator eq 'DFHDR') {
-    $indicator = 'HEADER';
-  } elsif ($header_trailer_indicator eq 'DFTRL') {
-    $indicator = 'TRAILER';
-  } elsif ($indicator eq 'UNKNOWN') {
-    my $summary_detail_indicator = join('-', substr($line, 42, 1), substr($line, 43, 2));
-    if ($summary_detail_indicator eq '1-00') {
-      $indicator = 'SUMMARY';
-    } elsif ($summary_detail_indicator eq '2-10') {
-      $indicator = 'SOC_DETAIL';
-    } elsif ($summary_detail_indicator eq '2-12') {
-      $indicator = 'SOC_PRICING';
-    } elsif ($summary_detail_indicator eq '3-11') {
-      $indicator = 'ROC_DETAIL';
-    } elsif ($summary_detail_indicator eq '3-13') {
-      $indicator = 'ROC_PRICING';
-    } elsif ($summary_detail_indicator eq '2-20') {
-      $indicator = 'CHARGEBACK_DETAIL';
-    } elsif ($summary_detail_indicator eq '2-30') {
-      $indicator = 'ADJUSTMENT_DETAIL';
-    } elsif ($summary_detail_indicator eq '2-40' or $summary_detail_indicator eq '2-41' or $summary_detail_indicator eq '2-50') {
-      $indicator = 'OTHER_DETAIL';
-    }
-  }
-  if (exists $self->{_type_map}->{$indicator}) {
+  if ($indicator and exists $self->{_type_map}->{$indicator}) {
     return $self->{_type_map}->{$indicator}->new(line => $line);
   }
+
   return Finance::AMEX::Transaction::EPPRC::Unknown->new(line => $line);
 }
 
@@ -105,7 +109,7 @@ Finance::AMEX::Transaction::EPPRC - Parse AMEX Transaction/Invoice Level Reconci
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -215,6 +219,21 @@ Returns one of the L<Finance::AMEX::Transaction::EPPRC::Header>, L<Finance::AMEX
 
  my $record = $epprc->parse_line('line from a epprc file');
 
+=head2 file_format
+
+This is included for compatibility, it will always return the string 'N/A'.
+
+=head2 file_version
+
+This is included for compatibility, it will always return the string 'N/A'.
+
+=head2 line_indicator
+
+Returns one of the line types for the EPPRC format.
+You wouldn't normally need to call this.
+
+ my $line_type = $epprc->line_indicator('line from a epprc file');
+
 =head1 NAME
 
 Finance::AMEX::Transaction::EPPRC - Parse AMEX Transaction/Invoice Level Reconciliation (EPPRC)
@@ -225,7 +244,7 @@ Tom Heady <cpan@punch.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by ZipRecruiter.
+This software is copyright (c) 2022 by ZipRecruiter/Tom Heady.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
