@@ -1,5 +1,5 @@
-package Finance::AMEX::Transaction::EPPRC::Detail::Chargeback;
-$Finance::AMEX::Transaction::EPPRC::Detail::Chargeback::VERSION = '0.004';
+package Finance::AMEX::Transaction::EPPRC::Detail::Chargeback 0.005;
+
 use strict;
 use warnings;
 
@@ -9,24 +9,23 @@ use base 'Finance::AMEX::Transaction::EPPRC::Base';
 
 sub field_map {
   return {
-
-    AMEX_PAYEE_NUMBER         => [1, 10],
-    AMEX_SE_NUMBER            => [11, 10],
-    SE_UNIT_NUMBER            => [21, 10],
-    PAYMENT_YEAR              => [31, 4],
-    PAYMENT_NUMBER            => [35, 8],
-    PAYMENT_NUMBER_DATE       => [35, 3],
-    PAYMENT_NUMBER_TYPE       => [38, 1],
-    PAYMENT_NUMBER_NUMBER     => [39, 4],
-    RECORD_TYPE               => [43, 1],
-    DETAIL_RECORD_TYPE        => [44, 2],
-    SE_BUSINESS_DATE          => [46, 7],
-    AMEX_PROCESS_DATE         => [53, 7],
-    SOC_INVOICE_NUMBER        => [60, 6],
-    SOC_AMOUNT                => [66, 11],
-    CHARGEBACK_AMOUNT         => [77, 9],
-    DISCOUNT_AMOUNT           => [86, 9],
-    SERVICE_FEE_AMOUNT        => [95, 7],
+    AMEX_PAYEE_NUMBER         => [1,   10],
+    AMEX_SE_NUMBER            => [11,  10],
+    SE_UNIT_NUMBER            => [21,  10],
+    PAYMENT_YEAR              => [31,  4],
+    PAYMENT_NUMBER            => [35,  8],
+    PAYMENT_NUMBER_DATE       => [35,  3],
+    PAYMENT_NUMBER_TYPE       => [38,  1],
+    PAYMENT_NUMBER_NUMBER     => [39,  4],
+    RECORD_TYPE               => [43,  1],
+    DETAIL_RECORD_TYPE        => [44,  2],
+    SE_BUSINESS_DATE          => [46,  7],
+    AMEX_PROCESS_DATE         => [53,  7],
+    SOC_INVOICE_NUMBER        => [60,  6],
+    SOC_AMOUNT                => [66,  11],
+    CHARGEBACK_AMOUNT         => [77,  9],
+    DISCOUNT_AMOUNT           => [86,  9],
+    SERVICE_FEE_AMOUNT        => [95,  7],
     NET_CHARGEBACK_AMOUNT     => [109, 9],
     DISCOUNT_RATE             => [118, 5],
     SERVICE_FEE_RATE          => [123, 5],
@@ -80,7 +79,7 @@ Finance::AMEX::Transaction::EPPRC::Detail::Chargeback - Parse AMEX Reconciliatio
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -127,6 +126,14 @@ Returns the full line that is represented by this object.
 
  print $record->line;
 
+=head2 field_map
+
+Returns an arrayref of hashrefs where the name is the record name and 
+the value is an arrayref of the start position and length of that field.
+
+ # print the start position of the PAYMENT_YEAR field
+ print $record->field_map->[3]->{PAYMENT_YEAR}->[0]; # 31
+
 =head2 AMEX_PAYEE_NUMBER
 
 This field contains the Service Establishment (SE) Number of the merchant that received the payment from American Express.
@@ -386,7 +393,7 @@ Note: Tilde (~) represents a character space.
 
 =head1 NAME
 
-Finance::AMEX::Transaction::EPPRC::Detail::Chargeback - Object methods for AMEX Reconciliation file chargback detail records.
+Finance::AMEX::Transaction::EPPRC::Detail::Chargeback - Object methods for AMEX Reconciliation file chargeback detail records.
 
 =head1 AUTHOR
 
@@ -394,7 +401,7 @@ Tom Heady <cpan@punch.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by ZipRecruiter.
+This software is copyright (c) 2022 by ZipRecruiter/Tom Heady.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
