@@ -1,5 +1,5 @@
-package Finance::AMEX::Transaction::EPTRN::Base;
-$Finance::AMEX::Transaction::EPTRN::Base::VERSION = '0.004';
+package Finance::AMEX::Transaction::EPTRN::Base 0.005;
+
 use strict;
 use warnings;
 
@@ -7,9 +7,7 @@ use warnings;
 
 sub new {
   my ($class, %props) = @_;
-  my $self = bless {
-    _line => $props{line},
-  }, $class;
+  my $self = bless {_line => $props{line}}, $class;
 
   return $self;
 }
@@ -30,7 +28,7 @@ sub _get_column {
   }
 
   my $ret = substr($self->{_line}, $map->[0] - 1, $map->[1]);
-  $ret =~ s{\s+\z}{};
+  $ret =~ s{\s+\z}{}xsm;
   return $ret;
 }
 
@@ -48,7 +46,7 @@ Finance::AMEX::Transaction::EPTRN::Base - Parse AMEX Transaction/Invoice Level R
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -74,7 +72,7 @@ Tom Heady <cpan@punch.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by ZipRecruiter.
+This software is copyright (c) 2022 by ZipRecruiter/Tom Heady.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
