@@ -1,5 +1,5 @@
-package Finance::AMEX::Transaction::GRRCN::TaxRecord;
-$Finance::AMEX::Transaction::GRRCN::TaxRecord::VERSION = '0.004';
+package Finance::AMEX::Transaction::GRRCN::TaxRecord 0.005;
+
 use strict;
 use warnings;
 
@@ -8,21 +8,21 @@ use warnings;
 use base 'Finance::AMEX::Transaction::GRRCN::Base';
 
 sub field_map {
-  return {
-    RECORD_TYPE                     => [1, 10],
-    PAYEE_MERCHANT_ID               => [11, 15],
-    SETTLEMENT_ACCOUNT_TYPE_CODE    => [26, 3],
-    AMERICAN_EXPRESS_PAYMENT_NUMBER => [29, 10],
-    PAYMENT_DATE                    => [39, 8],
-    PAYMENT_CURRENCY                => [47, 3],
-
-    TAX_TYPE_CODE                   => [50, 2],
-    TAX_DESCRIPTION                 => [52, 64],
-    TAX_BASE_AMOUNT                 => [116, 24],
-    TAX_PRESENT_DATE                => [140, 8],
-    TAX_RATE                        => [148, 20],
-    TAX_AMOUNT                      => [168, 24],
-  };
+  return [
+    {RECORD_TYPE                     => [1,   10]},
+    {PAYEE_MERCHANT_ID               => [11,  15]},
+    {SETTLEMENT_ACCOUNT_TYPE_CODE    => [26,  3]},
+    {AMERICAN_EXPRESS_PAYMENT_NUMBER => [29,  10]},
+    {PAYMENT_DATE                    => [39,  8]},
+    {PAYMENT_CURRENCY                => [47,  3]},
+    {TAX_TYPE_CODE                   => [50,  2]},
+    {TAX_DESCRIPTION                 => [52,  64]},
+    {TAX_BASE_AMOUNT                 => [116, 24]},
+    {TAX_PRESENT_DATE                => [140, 8]},
+    {TAX_RATE                        => [148, 20]},
+    {TAX_AMOUNT                      => [168, 24]},
+    {FILLER1                         => [192, 609]},
+  ];
 }
 
 sub type {return 'TAXRECORD'}
@@ -54,7 +54,7 @@ Finance::AMEX::Transaction::GRRCN::TaxRecord - Parse AMEX Global Reconciliation
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -101,6 +101,14 @@ Returns the full line that is represented by this object.
 
  print $record->line;
 
+=head2 field_map
+
+Returns an arrayref of hashrefs where the name is the record name and 
+the value is an arrayref of the start position and length of that field.
+
+ # print the start position of the PAYMENT_DATE field
+ print $record->field_map->[4]->{PAYMENT_DATE}->[0]; # 39
+
 =head2 RECORD_TYPE
 
 This field contains the Record identifier, which will always be “TAXRECORD” for the Tax Record(s).
@@ -217,7 +225,7 @@ Tom Heady <cpan@punch.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by ZipRecruiter.
+This software is copyright (c) 2022 by ZipRecruiter/Tom Heady.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
