@@ -1,5 +1,5 @@
-package Finance::AMEX::Transaction::GRRCN::Transaction;
-$Finance::AMEX::Transaction::GRRCN::Transaction::VERSION = '0.004';
+package Finance::AMEX::Transaction::GRRCN::Transaction 0.005;
+
 use strict;
 use warnings;
 
@@ -10,56 +10,49 @@ use base 'Finance::AMEX::Transaction::GRRCN::Base';
 sub field_map {
   my ($self) = @_;
 
-  return {
-    RECORD_TYPE                             => [1, 10],
-    PAYEE_MERCHANT_ID                       => [11, 15],
-    SETTLEMENT_ACCOUNT_TYPE_CODE            => [26, 3],
-    AMERICAN_EXPRESS_PAYMENT_NUMBER         => [29, 10],
-    PAYMENT_DATE                            => [39, 8],
-    PAYMENT_CURRENCY                        => [47, 3],
-
-    SUBMISSION_MERCHANT_ID                  => [50, 15],
-    BUSINESS_SUBMISSION_DATE                => [65, 8],
-    AMERICAN_EXPRESS_PROCESSING_DATE        => [73, 18],
-    SUBMISSION_INVOICE_NUMBER               => [81, 15],
-    SUBMISSION_CURRENCY                     => [96, 3],
-
-    MERCHANT_LOCATION_ID                    => [99, 15],
-    INVOICE_REFERENCE_NUMBER                => [114, 30],
-    SELLER_ID                               => [144, 20],
-    CARDMEMBER_ACCOUNT_NUMBER               => [164, 19],
-    INDUSTRY_SPECIFIC_REFERENCE_NUMBER      => [183, 30],
-    SUBMISSION_GROSS_AMOUNT                 => [213, 16],
-    TRANSACTION_AMOUNT                      => [229, 16],
-    TRANSACTION_DATE                        => [245, 8],
-    TRANSACTION_TIME                        => [253, 6],
-    TRANSACTION_ID                          => [259, 15],
-    APPROVAL_CODE                           => [274, 6],
-    TERMINAL_ID                             => [280, 10],
-    MERCHANT_CATEGORY_CODE                  => [290, 4],
-    CARDMEMBER_REFERENCE_NUMBER             => [294, 30],
-    ACQUIRER_REFERENCE_NUMBER               => [324, 23],
-    DATA_QUALITY_NON_COMPLIANT_INDICATOR    => [347, 1],
-    DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_1 => [348, 4],
-    DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_2 => [352, 4],
-    DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_3 => [356, 4],
-    DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_4 => [360, 4],
-    NON_SWIPED_INDICATOR                    => [364, 1],
-    TRANSACTION_REJECTED_INDICATOR          => [365, 3],
-    FIRST_INSTALLMENT_AMOUNT                => [368, 16],
-    SUBSEQUENT_INSTALLMENT_AMOUNT           => [384, 16],
-    NUMBER_OF_INSTALLMENTS                  => [400, 5],
-    INSTALLMENT_NUMBER                      => [405, 5],
-
-    (
-      $self->version >= 2.01
-      ? ( FILLER => [410, 15] )
-      : ()
-    ),
-
-    SERVICE_FEE_AMOUNT                      => [425, 16],
-    ACCELERATION_AMOUNT                     => [441, 16],
-  };
+  return [
+    {RECORD_TYPE                             => [1,   10]},
+    {PAYEE_MERCHANT_ID                       => [11,  15]},
+    {SETTLEMENT_ACCOUNT_TYPE_CODE            => [26,  3]},
+    {AMERICAN_EXPRESS_PAYMENT_NUMBER         => [29,  10]},
+    {PAYMENT_DATE                            => [39,  8]},
+    {PAYMENT_CURRENCY                        => [47,  3]},
+    {SUBMISSION_MERCHANT_ID                  => [50,  15]},
+    {BUSINESS_SUBMISSION_DATE                => [65,  8]},
+    {AMERICAN_EXPRESS_PROCESSING_DATE        => [73,  8]},
+    {SUBMISSION_INVOICE_NUMBER               => [81,  15]},
+    {SUBMISSION_CURRENCY                     => [96,  3]},
+    {MERCHANT_LOCATION_ID                    => [99,  15]},
+    {INVOICE_REFERENCE_NUMBER                => [114, 30]},
+    {SELLER_ID                               => [144, 20]},
+    {CARDMEMBER_ACCOUNT_NUMBER               => [164, 19]},
+    {INDUSTRY_SPECIFIC_REFERENCE_NUMBER      => [183, 30]},
+    {SUBMISSION_GROSS_AMOUNT                 => [213, 16]},
+    {TRANSACTION_AMOUNT                      => [229, 16]},
+    {TRANSACTION_DATE                        => [245, 8]},
+    {TRANSACTION_TIME                        => [253, 6]},
+    {TRANSACTION_ID                          => [259, 15]},
+    {APPROVAL_CODE                           => [274, 6]},
+    {TERMINAL_ID                             => [280, 10]},
+    {MERCHANT_CATEGORY_CODE                  => [290, 4]},
+    {CARDMEMBER_REFERENCE_NUMBER             => [294, 30]},
+    {ACQUIRER_REFERENCE_NUMBER               => [324, 23]},
+    {DATA_QUALITY_NON_COMPLIANT_INDICATOR    => [347, 1]},
+    {DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_1 => [348, 4]},
+    {DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_2 => [352, 4]},
+    {DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_3 => [356, 4]},
+    {DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_4 => [360, 4]},
+    {NON_SWIPED_INDICATOR                    => [364, 1]},
+    {TRANSACTION_REJECTED_INDICATOR          => [365, 3]},
+    {FIRST_INSTALLMENT_AMOUNT                => [368, 16]},
+    {SUBSEQUENT_INSTALLMENT_AMOUNT           => [384, 16]},
+    {NUMBER_OF_INSTALLMENTS                  => [400, 5]},
+    {INSTALLMENT_NUMBER                      => [405, 5]},
+    {FILLER1                                 => [410, 15]},
+    {SERVICE_FEE_AMOUNT                      => [425, 16]},
+    {ACCELERATION_AMOUNT                     => [441, 16]},
+    {FILLER2                                 => [457, 344]},
+  ];
 }
 
 sub type {return 'TRANSACTION'}
@@ -69,15 +62,12 @@ sub PAYEE_MERCHANT_ID                       {return $_[0]->_get_column('PAYEE_ME
 sub SETTLEMENT_ACCOUNT_TYPE_CODE            {return $_[0]->_get_column('SETTLEMENT_ACCOUNT_TYPE_CODE')}
 sub AMERICAN_EXPRESS_PAYMENT_NUMBER         {return $_[0]->_get_column('AMERICAN_EXPRESS_PAYMENT_NUMBER')}
 sub PAYMENT_DATE                            {return $_[0]->_get_column('PAYMENT_DATE')}
-sub FILLER                                  {return $_[0]->_get_column('FILLER')}
-
 sub PAYMENT_CURRENCY                        {return $_[0]->_get_column('PAYMENT_CURRENCY')}
 sub SUBMISSION_MERCHANT_ID                  {return $_[0]->_get_column('SUBMISSION_MERCHANT_ID')}
 sub BUSINESS_SUBMISSION_DATE                {return $_[0]->_get_column('BUSINESS_SUBMISSION_DATE')}
 sub AMERICAN_EXPRESS_PROCESSING_DATE        {return $_[0]->_get_column('AMERICAN_EXPRESS_PROCESSING_DATE')}
 sub SUBMISSION_INVOICE_NUMBER               {return $_[0]->_get_column('SUBMISSION_INVOICE_NUMBER')}
 sub SUBMISSION_CURRENCY                     {return $_[0]->_get_column('SUBMISSION_CURRENCY')}
-
 sub MERCHANT_LOCATION_ID                    {return $_[0]->_get_column('MERCHANT_LOCATION_ID')}
 sub INVOICE_REFERENCE_NUMBER                {return $_[0]->_get_column('INVOICE_REFERENCE_NUMBER')}
 sub SELLER_ID                               {return $_[0]->_get_column('SELLER_ID')}
@@ -94,7 +84,6 @@ sub MERCHANT_CATEGORY_CODE                  {return $_[0]->_get_column('MERCHANT
 sub CARDMEMBER_REFERENCE_NUMBER             {return $_[0]->_get_column('CARDMEMBER_REFERENCE_NUMBER')}
 sub ACQUIRER_REFERENCE_NUMBER               {return $_[0]->_get_column('ACQUIRER_REFERENCE_NUMBER')}
 sub DATA_QUALITY_NON_COMPLIANT_INDICATOR    {return $_[0]->_get_column('DATA_QUALITY_NON_COMPLIANT_INDICATOR')}
-
 sub DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_1 {return $_[0]->_get_column('DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_1')}
 sub DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_2 {return $_[0]->_get_column('DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_2')}
 sub DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_3 {return $_[0]->_get_column('DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_3')}
@@ -108,7 +97,6 @@ sub INSTALLMENT_NUMBER                      {return $_[0]->_get_column('INSTALLM
 sub SERVICE_FEE_AMOUNT                      {return $_[0]->_get_column('SERVICE_FEE_AMOUNT')}
 sub ACCELERATION_AMOUNT                     {return $_[0]->_get_column('ACCELERATION_AMOUNT')}
 
-
 1;
 
 __END__
@@ -123,7 +111,7 @@ Finance::AMEX::Transaction::GRRCN::Transaction - Parse AMEX Global Reconciliatio
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -170,6 +158,14 @@ Returns the full line that is represented by this object.
 
  print $record->line;
 
+=head2 field_map
+
+Returns an arrayref of hashrefs where the name is the record name and 
+the value is an arrayref of the start position and length of that field.
+
+ # print the start position of the PAYMENT_DATE field
+ print $record->field_map->[4]->{PAYMENT_DATE}->[0]; # 39
+
 =head2 RECORD_TYPE
 
 This field contains the Record identifier, which will always be “TRANSACTN” for the Transaction Record.
@@ -400,7 +396,7 @@ Valid values include the following:
 
 This field is only applicable in the U.S. and Canada. Where not relevant this field will be character space filled (fixed format) or blank (delimited formats).
 
-=head2 DATA_QUALITY_NON-COMPLIANT_ERROR_CODE_1, DATA_QUALITY_NON-COMPLIANT_ERROR_CODE_2, DATA_QUALITY_NON-COMPLIANT_ERROR_CODE_3, DATA_QUALITY_NON-COMPLIANT_ERROR_CODE_4
+=head2 DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_1 DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_2 DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_3 DATA_QUALITY_NON_COMPLIANT_ERROR_CODE_4
 
 These fields contain field-level Non-compliant Error Code(s) applicable to this transaction.
 
@@ -532,7 +528,7 @@ Tom Heady <cpan@punch.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by ZipRecruiter.
+This software is copyright (c) 2022 by ZipRecruiter/Tom Heady.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
